Bqgpd_c: Bayesian predictive quantile for generalized Pareto...

View source: R/Prediction.R

Bqgpd_cR Documentation

Bayesian predictive quantile for generalized Pareto distribution

Description

WARNING: this function will not be exported in a future version of the package.

Usage

Bqgpd_c(p, post, lower, upper)

Arguments

p

probability levels

post

matrix of posterior samples

lower

lower bound for the search for the quantile

upper

upper bound for the region over which to search for the quantile

Value

a vector of quantiles of the same length as p


ExtremeRisks documentation built on Nov. 5, 2025, 7:05 p.m.