View source: R/Estimation.R View source: R/UniEstimation.R
| estExtLevel | R Documentation |
Estimates the expectile's extreme level corresponding to a quantile's extreme level.
estExtLevel(alpha_n, data=NULL, gammaHat=NULL, VarGamHat=NULL, tailest="Hill", k=NULL,
var=FALSE, varType="asym-Dep", bigBlock=NULL, smallBlock=NULL, alpha=0.05)
alpha_n |
A real in |
data |
A vector of |
gammaHat |
A real specifying an estimate of the tail index. By default |
VarGamHat |
A real specifying an estimate of the variance of the tail index estimate. By default |
tailest |
A string specifying the type of tail index estimator to be used. By default |
k |
An integer specifying the value of the intermediate sequence |
var |
If |
varType |
A string specifying the asymptotic variance to compute. By default |
bigBlock |
An interger specifying the size of the big-block used to estimaste the asymptotic variance. See Details. |
smallBlock |
An interger specifying the size of the small-block used to estimaste the asymptotic variance. See Details. |
alpha |
A real in |
For a given extreme level \alpha_n for the \alpha_n-th quantile, an estimate of the extreme level \tau_n'(\alpha_n) is computed such that \xi_{\tau_n'(\alpha_n)}=q_{\alpha_n}. The estimator is defined by
\hat{\tau}_n'(\alpha_n) = 1 - (1 - \alpha_n)\frac{\hat{\gamma}_n}{1-\hat{\gamma}_n}
where \hat{\gamma}_n is a consistent estimator of the tail index \gamma. If a value for the parameter gammaHat is given, then such a value is used to compute \hat{\tau}_n'. If gammaHat is NULL and a dataset is provided through the parameter data, then the tail index \gamma is estimated by a suitable estimator \hat{\gamma}_n. See Section 6 in Padoan and Stupfler (2020) for more details.
If VarGamHat is specified, i.e. the variance of the tail index estimator, then the variance of the extreme level estimator \hat{\tau}_n' is computed by using such value.
When estimating the tail index, if tailest='Hill' then \gamma is estimated using the Hill estimator (see also HTailIndex). If tailest='ML' then \gamma is estimated using the Maximum Likelihood estimator (see MLTailIndex).
If tailest='ExpBased' then \gamma is estimated using the expectile based estimator (see EBTailIndex).
If tailest='Moment' then \gamma is estimated using the moment based estimator (see MomTailIndex). See Padoan and Stupfler (2020) for details.
k or k_n is the value of the so-called intermediate sequence k_n, n=1,2,\ldots. Its represents a sequence of positive integers such that k_n \to \infty and k_n/n \to 0 as n \to \infty. Practically, when tailest="Hill" then the value k_n specifies the number of k+1 larger order statistics to be used to estimate \gamma by the Hill estimator. See MLTailIndex, EBTailIndex and MomTailIndex for the other estimators.
If var=TRUE then the asymptotic variance of the extreme level estimator is computed by applying the delta method, i.e.
Var(\tau_n') = Var(\hat{\gamma}_n) * (\alpha_n-1)^2 / (1-\hat{\gamma}_n)^4
where Var(\hat{\gamma}_n is provided by VarGamHat or is estimated when esitmating the tail index through tailest='Hill' and tailest='ML'. See HTailIndex and MLTailIndex for details on how the variance is computed.
Given a small value \alpha\in (0,1) then an asymptotic confidence interval for the extreme level, \tau_n'(\alpha_n), with approximate nominal confidence level (1-\alpha)100\% is computed.
A list with elements:
tauHat: an estimate of the extreme level \tau_n';
tauVar: an estimate of the asymptotic variance of the extreme level estimator \hat{\tau}_n'(\alpha_n);
tauCI: an estimate of the approximate (1-\alpha)100\% confidence interval for the extreme level \tau_n'(\alpha_n).
Simone Padoan, simone.padoan@unibocconi.it, https://faculty.unibocconi.it/simonepadoan/; Gilles Stupfler, gilles.stupfler@univ-angers.fr, https://math.univ-angers.fr/~stupfler/
Anthony C. Davison, Simone A. Padoan and Gilles Stupfler (2023). Tail Risk Inference via Expectiles in Heavy-Tailed Time Series, Journal of Business & Economic Statistics, 41(3) 876-889.
Daouia, A., Girard, S. and Stupfler, G. (2018). Estimation of tail risk based on extreme expectiles. Journal of the Royal Statistical Society: Series B, 80, 263-292.
estExpectiles, predExpectiles, extQuantile
# Extreme level estimation for a given quantile's extreme level alpha_n
# obtained with 1-dimensional data simulated from an AR(1) with Student-t innovations
tsDist <- "studentT"
tsType <- "AR"
# parameter setting
corr <- 0.8
df <- 3
par <- c(corr, df)
# Big- small-blocks setting
bigBlock <- 65
smallBlock <- 15
# quantile's extreme level
alpha_n <- 0.999
# sample size
ndata <- 2500
# Simulates a sample from an AR(1) model with Student-t innovations
data <- rtimeseries(ndata, tsDist, tsType, par)
# expectile's extreme level estimation
tau1Hat <- estExtLevel(alpha_n, data, var=TRUE, k=150, bigBlock=bigBlock,
smallBlock=smallBlock)
tau1Hat
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.