| Bqgpd_c | R Documentation |
WARNING: this function will not be exported in a future version of the package.
Bqgpd_c(p, post, lower, upper)
p |
probability levels |
post |
matrix of posterior samples |
lower |
lower bound for the search for the quantile |
upper |
upper bound for the region over which to search for the quantile |
a vector of quantiles of the same length as p
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.