| testTailHomo | R Documentation |
Given observed samples and effective sample size, return the results for a likelihood ratio-type test on tail homogeneity.
testTailHomo(y, k, alpha = 0.05)
y |
list, containing the samples on which the test is to be performed |
k |
integer, number of exceedances for the generalized Pareto |
alpha |
double indicating the confidence level for the test. Default: 0.05 |
list of 7 containing
gamHatP the pooled tail index
VarGamHatP the variance of gamHatP
CIGamHatP (1-\alpha) level confidence interval for gamHatP
BiasGamHatP bias term of gamHatP
logLikR value of the likelihood ratio-type of test statistic
PVal p-value of the test
Daouia, A., S.A. Padoan and G. Stupfler (2024). Optimal weighted pooling for inference about the tail index and extreme quantiles, Bernoulli, 30(2), pp. 1287–1312.
## Not run:
# generate two samples of data
set.seed(1234)
y1 <- evd::rgpd(500, 0, 1, 0.2)
y2 <- evd::rgpd(700, 0, 2, 0.7)
y <- list(y1 = y1, y2 = y2)
# set effective sample size
k <- 50
# perform test
test <- testTailHomo(y,k)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.